#
# spec file for package cosmic-workspaces
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appname com.system76.CosmicWorkspaces
Name:           cosmic-workspaces
Version:        1.0.0~alpha6+0
Release:        1.1
Summary:        COSMIC workspaces
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-workspaces-epoch
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xkbcommon)

%description
%{summary}.

%prep
%autosetup -a1

%build
%make_build

%install
%make_install DESTDIR=%{buildroot} prefix=%{_prefix}

%check
%{cargo_test}

%files
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/applications/%{appname}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{appname}.svg

%changelog
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * fix: invert scroll direction
  * Polish translation for .desktop entry
  * Update for toplevel-info cctk changes
  * Fix build with `mock-backend` feature
  * Fix warnings and remove `dbg!`
  * UI code for supporting workspace drags
  * Rename `DndWorkspaceDrag` to `DndToplevelDrag`
  * toplevel_layout: Add `AxisToplevelLayout` helper
  * toplevel_layout: Make size depend on axis
  * toplevel_layout: Move logic into a `requested_main_total` method
  * Fix disabled scroll accumulation
  * Accumulate scroll events
  * Change workspace based on scroll events
  * Use updated screencopy abstraction
  * Add `workspaces_for_output` helper function
  * Allow dropping window onto toplevel list area
  * Remove unneeded field of `DragSurface`
  * Fix building mock backend
  * Move drag-and-drop related types to a `dnd` module
  * `DropTarget` enum instead of tuple; combine with `DragId`
  * view: Add `DragId` helper to manage multiple types of destinations
  * feat: Workspace view closing by pressing current workspace or empty space
  * Center toplevels if they don't fill space
  * Have `icon_for_app_id` run in a background thread
  * performance: Add app_id check to throttle icon fetch
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+7:
  * Remove `LayerShell` only once iced confirms surface destroyed
  * Use std `LazyLock` instead of `once_cell` crate
  * Address some warnings
  * Allow a couple clippy lints
  * Run `cargo clippy --fix`
  * fix(interface): align closer to designs
  * Apply screencopy `transform` to subsurfaces
  * Run `cargo update`
  * Toplevel layout abstraction
  * Update dependencies
  * Update iced/libcosmic
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+0:
  * On mock backend, don't hide when toplevel is opened
  * Fix building with `mock-backend` and `no-subsurfaces`
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * Don't panic if `dmabuf` global isn't present
  * Run `cargo update`
  * Close workspaces view if window spawns while open
  * Correctly restrict modifiers in screencopy
  * chore(desktop-file): remove ICED category
  * Don't show background; rely on cosmic-comp for that
  * Deduplicate `drag_surface` code a bit
  * support CARGO_TARGET_DIR
  * Move drag surface view into a function
  * Run `cargo update`
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * no difference to alpha2
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * Don't panic if dmabuf global isn't present
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * Close workspaces view if window spawns while open
  * Correctly restrict modifiers in screencopy
  * chore(desktop-file): remove ICED category
  * Don't show background; rely on cosmic-comp for that
- enable leap (thanks to vyvir)
* Thu Mar 14 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
